summaryrefslogtreecommitdiffstats
path: root/tdeui/kxmlguifactory.h
diff options
context:
space:
mode:
Diffstat (limited to 'tdeui/kxmlguifactory.h')
-rw-r--r--tdeui/kxmlguifactory.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/tdeui/kxmlguifactory.h b/tdeui/kxmlguifactory.h
index 9b4733790..2f225b5ba 100644
--- a/tdeui/kxmlguifactory.h
+++ b/tdeui/kxmlguifactory.h
@@ -28,11 +28,11 @@
#include <tdelibs_export.h>
-class KAction;
+class TDEAction;
class KXMLGUIFactoryPrivate;
class KXMLGUIClient;
class KXMLGUIBuilder;
-class KInstance;
+class TDEInstance;
namespace KXMLGUI
{
@@ -52,7 +52,7 @@ class BuildHelper;
* and merging the GUI from an unlimited number of clients.
*
* Each client provides XML through a TQDomDocument and actions through a
* KActionCollection . The XML document contains the rules for how to merge the
* GUI.
*
* KXMLGUIFactory processes the DOM tree provided by a client and plugs in the client's actions,
@@ -79,10 +79,10 @@ class TDEUI_EXPORT KXMLGUIFactory : public TQObject
~KXMLGUIFactory();
// XXX move to somewhere else? (Simon)
- static TQString readConfigFile( const TQString &filename, bool never_null, const KInstance *instance = 0 );
- static TQString readConfigFile( const TQString &filename, const KInstance *instance = 0 );
+ static TQString readConfigFile( const TQString &filename, bool never_null, const TDEInstance *instance = 0 );
+ static TQString readConfigFile( const TQString &filename, const TDEInstance *instance = 0 );
static bool saveConfigFile( const TQDomDocument& doc, const TQString& filename,
- const KInstance *instance = 0 );
+ const TDEInstance *instance = 0 );
static TQString documentToXML( const TQDomDocument& doc );
static TQString elementToXML( const TQDomElement& elem );
@@ -124,7 +124,7 @@ class TDEUI_EXPORT KXMLGUIFactory : public TQObject
*/
void removeClient( KXMLGUIClient *client );
- void plugActionList( KXMLGUIClient *client, const TQString &name, const TQPtrList<KAction> &actionList );
+ void plugActionList( KXMLGUIClient *client, const TQString &name, const TQPtrList<TDEAction> &actionList );
void unplugActionList( KXMLGUIClient *client, const TQString &name );
/**
@@ -206,8 +206,8 @@ class TDEUI_EXPORT KXMLGUIFactory : public TQObject
TQPtrList<TQWidget> findRecursive( KXMLGUI::ContainerNode *node, const TQString &tagName );
void applyActionProperties( const TQDomElement &element );
- void configureAction( KAction *action, const TQDomNamedNodeMap &attributes );
- void configureAction( KAction *action, const TQDomAttr &attribute );
+ void configureAction( TDEAction *action, const TQDomNamedNodeMap &attributes );
+ void configureAction( TDEAction *action, const TQDomAttr &attribute );
protected:
virtual void virtual_hook( int id, void* data );
@@ -52,7 +52,7 @@ class BuildHelper;
*
* Each client provides XML through a TQDomDocument and actions through a
- * KActionCollection . The XML document contains the rules for how to merge the
+ * TDEActionCollection . The XML document contains the rules for how to merge the
* GUI.
*